@@ -132,7 +132,7 @@ class Instrument:
 
     def __hash__(self):
         return int(self.code)
-    
+
     @property
     async def l18(self) -> str:
         if (l18 := self._l18) is not None:
@@ -256,7 +256,11 @@ class Instrument:
         # return the same response.
         text = await _get_data(
             'instinfodata.aspx'
-            # &e=1 parameter is required to get NAV
+            # &e=1 parameter is required to get cancel NAV for ETFs but it 
+            # seems to be ignored if no NAV is defined for the instrument.
+            # &c= is normally set to CSecVal, but does not seem to be required.
+            # CSecVal is idustry group code:
+            # http://redirectcdn.tsetmc.com/Site.aspx?ParTree=111411111B&LnkIdn=107
             f'?i={self.code}&c=&e=1', fa=True)
         # the _s are unknown
         try:
@@ -717,12 +721,13 @@ def _parse_price_info(price_info):
         tno,  # 8
         tvol,  # 9
         tval,  # 10
-        _,  # 11
+        _,  # 11 is used to add css styles for pc/pl, not important.
         info_datetime_date,  # 12
         last_info_time,  # 13
         nav_datetime,  # 14
         nav  # 15
     ) = price_info
+
     result = {
         'timestamp': timestamp, 'status': status
         , 'datetime': _strptime(
@@ -730,7 +735,9 @@ def _parse_price_info(price_info):
         , 'pl': int(pl), 'pc': int(pc), 'pf': int(pf), 'py': int(py)
         , 'pmin': int(pmin), 'pmax': int(pmax)
         , 'tno': int(tno), 'tvol': int(tvol), 'tval': int(tval)}
+
     if nav:
         result['nav'] = int(nav)
         result['nav_datetime'] = _jstrptime(nav_datetime, '%Y/%m/%d %H:%M:%S')
+
     return result
